const path = require('path');
const webpack = require('webpack');
var HtmlWebpackPlugin = require('html-webpack-plugin');
var ExtractTextPlugin =
  require('extract-text-webpack-plugin');

function resolve (dir) {
  return path.join(__dirname, dir);
}
var ip = '';
if (!require('os').networkInterfaces().en0)
  ip = 'localhost';
else {
  for (let item of require('os').networkInterfaces().en0) {
    if (item.family === 'IPv4') {
      ip = item.address;
    }
  }
}

module.exports = {
  'entry': {
    'index': './src/index.js'
  },

  'output': {
    'path': path.join(__dirname, 'src'),
    'filename': 'js/[name].bundle.js'
  },

  'resolve': {
    'extensions': ['.js', '.vue', '.json'],
    'alias': {
      'vue$': 'vue/dist/vue.esm.js',
      '@': resolve('src')
    }
  },

  'plugins': [
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: JSON.stringify('development')
      }
    }),
    new webpack.HotModuleReplacementPlugin(),
    new webpack.NamedModulesPlugin(), // HMR shows correct file names in console on update.
    new webpack.NoEmitOnErrorsPlugin(),
    new HtmlWebpackPlugin({
      'filename': './index.html', // 相对publicPath
      'template': './src/index.tpl.html', // 相对config
      'inject': 'body',
      'hash': true
    }),
    new ExtractTextPlugin('css/[name].bundle.css')
  ],

  'module': {
    'rules': [
      {
        'test': /\.js/,
        'use': { 'loader': 'babel-loader' },
        'exclude': /node_modules/
      },
      {
        'test': /\.vue$/,
        'loader': 'vue-loader',
        'options': {
          'loaders': {
            scss: ['vue-style-loader', { 'loader': 'css-loader', 'options': { 'sourceMap': true } },
              { 'loader': 'sass-loader', 'options': { 'sourceMap': true } },
              { 'loader': 'postcss-loader', 'options': { 'sourceMap': true } }],
            css: ['vue-style-loader', { 'loader': 'css-loader', 'options': { 'sourceMap': true } },
              { 'loader': 'postcss-loader', 'options': { 'sourceMap': true } }]
          },
          cssSourceMap: true,
          cacheBusting: true,
          transformToRequire: {
            video: ['src', 'poster'],
            source: 'src',
            img: 'src',
            image: 'xlink:href'
          }
        }
      },
      {
        'test': /\.(css)/,
        'use': ['style-loader', { 'loader': 'css-loader', 'options': { 'sourceMap': true } },
          { 'loader': 'postcss-loader', 'options': { 'sourceMap': true } }]
      },
      {
        'test': /\.(scss)/,
        'use': ['style-loader', { 'loader': 'css-loader', 'options': { 'sourceMap': true } },
          { 'loader': 'sass-loader', 'options': { 'sourceMap': true } },
          { 'loader': 'postcss-loader', 'options': { 'sourceMap': true } }]
      },
      {
        'test': /\.(png|jpe?g|gif|svg|mp3)(\?.*)?$/,
        'loader': 'url-loader',
        'options': {
          'limit': 10000,
          'name': 'img/[name].[hash:7].[ext]'
        }
      }
    ]
  },

  'devServer': {
    'compress': true,
    'contentBase': path.join(__dirname, 'public'),
    'disableHostCheck': true,
    'host': ip,
    'port': 3000,
    'hot': true,
    // 'quiet': true,
    'watchOptions': {
      poll: false
    },
    'proxy': {
      '/proxy': {
        target: 'https://beta-api.m.jd.com/client.action',
        changeOrigin: true,
        pathRewrite: {
          '^/proxy': ''
        }
      },
      '/proxy_formal': {
        target: 'https://api.m.jd.com/client.action',
        changeOrigin: true,
        pathRewrite: {
          '^/proxy_formal': ''
        }
      }
    }
  },
  'devtool': 'cheap-module-eval-source-map' // '#source-map'
};
