const path = require('path');
const webpack = require('webpack');
const OptimizeCSSPlugin = require('optimize-css-assets-webpack-plugin')
const UglifyJsPlugin = require('uglifyjs-webpack-plugin')

function resolve (dir) {
  return path.join(__dirname, dir);
}

module.exports = {
  'entry': {
    'index': './src/toast/index.js'
  },

  'output': {
    path: path.join(__dirname, 'build'),
    filename: 'tz-vue-toast.min.js',
    library: 'TZVueToast',
    libraryTarget: 'umd', // libraryTarget会生成不同umd的代码,可以只是commonjs标准的，也可以是指amd标准的，也可以只是通过script标签引入的。
    umdNamedDefine: true // 会对 UMD 的构建过程中的 AMD 模块进行命名。否则就使用匿名的 define。
  },

  'resolve': {
    'extensions': ['.js', '.vue', '.json'],
    'alias': {
      'vue$': 'vue/dist/vue.esm.js',
      '@': resolve('src')
    }
  },

  'plugins': [
    new webpack.DefinePlugin({
      'process.env': {
        'NODE_ENV': JSON.stringify('production')
      }
    }),
    new OptimizeCSSPlugin({
      cssProcessorOptions: { safe: true, map: { inline: false }, autoprefixer: false }
    }),
    new UglifyJsPlugin({
      uglifyOptions: {
        compress: {
          warnings: false,
          drop_debugger: true,
          drop_console: true
        }
      },
      sourceMap: true,
      parallel: true
    })
  ],

  'module': {
    'rules': [
      {
        'test': /\.js/,
        'use': { 'loader': 'babel-loader' },
        'exclude': /node_modules/
      },
      {
        'test': /\.vue$/,
        'loader': 'vue-loader',
        'options': {
          'loaders': {
            scss: ['vue-style-loader', { 'loader': 'css-loader', 'options': { 'sourceMap': true } },
              { 'loader': 'sass-loader', 'options': { 'sourceMap': true } },
              { 'loader': 'postcss-loader', 'options': { 'sourceMap': true } }],
            css: ['vue-style-loader', { 'loader': 'css-loader', 'options': { 'sourceMap': true } },
              { 'loader': 'postcss-loader', 'options': { 'sourceMap': true } }]
          },
          cssSourceMap: true,
          cacheBusting: true,
          transformToRequire: {
            video: ['src', 'poster'],
            source: 'src',
            img: 'src',
            image: 'xlink:href'
          }
        }
      },
      {
        'test': /\.(css)/,
        'use': ['style-loader', { 'loader': 'css-loader', 'options': { 'sourceMap': true } },
          { 'loader': 'postcss-loader', 'options': { 'sourceMap': true } }]
      },
      {
        'test': /\.(scss)/,
        'use': ['style-loader', { 'loader': 'css-loader', 'options': { 'sourceMap': true } },
          { 'loader': 'sass-loader', 'options': { 'sourceMap': true } },
          { 'loader': 'postcss-loader', 'options': { 'sourceMap': true } }]
      }
    ]
  }
};
